% Auto-generated chapter 21 for ibnmajah
% Hadiths in this chapter: 80

\hadithdefcmd{ibnmajah}{2615}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالُوا حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ يَوْمَ الْقِيَامَةِ فِي الدِّمَاءِ ‏"‏ ‏.‏\hadithno{2615}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abdullah that the Messenger of Allah (ﷺ) said:“The first matter concerning which judgment will be passed among the people on the Day of Resurrection will be bloodshed.”}}
\hadithdefcmd{ibnmajah}{2616}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقْتَلُ نَفْسٌ ظُلْمًا إِلاَّ كَانَ عَلَى ابْنِ آدَمَ الأَوَّلِ كِفْلٌ مِنْ دَمِهَا لأَنَّهُ أَوَّلُ مَنْ سَنَّ الْقَتْلَ ‏"‏ ‏.‏\hadithno{2616}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abdullah that the Messenger of Allah (ﷺ) said:“No person is killed wrongfully, but a share of responsibility for his blood will be upon, the first son of Adam, because he was the first one to kill.”}}
\hadithdefcmd{ibnmajah}{2617}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ الأَزْهَرِ الْوَاسِطِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ شَرِيكٍ، عَنْ عَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ يَوْمَ الْقِيَامَةِ فِي الدِّمَاءِ ‏"‏ ‏.‏\hadithno{2617}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abdullah that the Messenger of Allah (ﷺ) said:The first matter concerning which judgment will be passed among the people on the Day of Resurrection will be bloodshed.”}}
\hadithdefcmd{ibnmajah}{2618}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَائِذٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَقِيَ اللَّهَ لاَ يُشْرِكُ بِهِ شَيْئًا لَمْ يَتَنَدَّ بِدَمٍ حَرَامٍ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{2618}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Uqbah bin Amir Al-Juhani that the Messenger of Allah (ﷺ) said:“Whoever meets Allah (SWT) not associating anything in worship with him, and not having shed any blood unlawfully, will enter Paradise.”}}
\hadithdefcmd{ibnmajah}{2619}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مَرْوَانُ بْنُ جَنَاحٍ، عَنْ أَبِي الْجَهْمِ الْجُوزَجَانِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَزَوَالُ الدُّنْيَا أَهْوَنُ عَلَى اللَّهِ مِنْ قَتْلِ مُؤْمِنٍ بِغَيْرِ حَقٍّ ‏"‏ ‏.‏\hadithno{2619}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Bara' bin Azib that the Messenger of Allah (ﷺ) said:“If this world were to be destroyed, that would be less significant before Allah (SWT) than the unlawful killing of a believer.”}}
\hadithdefcmd{ibnmajah}{2620}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا يَزِيدُ بْنُ زِيَادٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعَانَ عَلَى قَتْلِ مُؤْمِنٍ بِشَطْرِ كَلِمَةٍ لَقِيَ اللَّهَ عَزَّ وَجَلَّ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ آيِسٌ مِنْ رَحْمَةِ اللَّهِ ‏"‏ ‏.‏\hadithno{2620}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever helps to kill a believer, even with half a world, he will meet Allah (SWT) with (the words) written between his eyes, 'He has no hope of the mercy of Allah (SWT).”}}
\hadithdefcmd{ibnmajah}{2621}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمَّارٍ الدُّهْنِيِّ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، قَالَ سُئِلَ ابْنُ عَبَّاسٍ عَمَّنْ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا ثُمَّ تَابَ وَآمَنَ وَعَمِلَ صَالِحًا ثُمَّ اهْتَدَى ‏.‏ قَالَ وَيْحَهُ وَأَنَّى لَهُ الْهُدَى سَمِعْتُ نَبِيَّكُمْ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَجِيءُ الْقَاتِلُ وَالْمَقْتُولُ يَوْمَ الْقِيَامَةِ مُتَعَلِّقٌ بِرَأْسِ صَاحِبِهِ يَقُولُ رَبِّ سَلْ هَذَا لِمَ قَتَلَنِي ‏"‏ ‏.‏ وَاللَّهِ لَقَدْ أَنْزَلَهَا اللَّهُ عَزَّ وَجَلَّ عَلَى نَبِيِّكُمْ ثُمَّ مَا نَسَخَهَا بَعْدَ مَا أَنْزَلَهَا ‏.‏\hadithno{2621}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Salim bin Abu Jad said:“Ibn Abbas was asked about one who kills a believer deliberately, then repents, believes, does righteous deeds and follows true guidance. He said: 'Woe to him can there be any guidance for him? I heard your Prophet (ﷺ) say: “The killer and his victim will be brought on the day of Resurrection, with slain holding onto the head of his killer, saying: 'O Lord, ask this one, why did he kill me?” By Allah (SWT), Allah (SWT) the Mighty and Sublime revealed it to your Prophet (ﷺ) then He did not abrogate it after He revealed it.”}}
\hadithdefcmd{ibnmajah}{2622}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا هَمَّامُ بْنُ يَحْيَى، عَنْ قَتَادَةَ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَلاَ أُخْبِرُكُمْ بِمَا، سَمِعْتُ مِنْ، فِي رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏"‏ إِنَّ عَبْدًا قَتَلَ تِسْعَةً وَتِسْعِينَ نَفْسًا ثُمَّ عَرَضَتْ لَهُ التَّوْبَةُ فَسَأَلَ عَنْ أَعْلَمِ أَهْلِ الأَرْضِ فَدُلَّ عَلَى رَجُلٍ فَأَتَاهُ ‏.‏ فَقَالَ إِنِّي قَتَلْتُ تِسْعَةً وَتِسْعِينَ نَفْسًا فَهَلْ لِي مِنْ تَوْبَةٍ قَالَ بَعْدَ تِسْعَةٍ وَتِسْعِينَ نَفْسًا ‏.‏ قَالَ فَانْتَضَى سَيْفَهُ فَقَتَلَهُ فَأَكْمَلَ بِهِ الْمِائَةَ ثُمَّ عَرَضَتْ لَهُ التَّوْبَةُ فَسَأَلَ عَنْ أَعْلَمِ أَهْلِ الأَرْضِ فَدُلَّ عَلَى رَجُلٍ فَأَتَاهُ فَقَالَ إِنِّي قَتَلْتُ مِائَةَ نَفْسٍ فَهَلْ لِي مِنْ تَوْبَةٍ قَالَ فَقَالَ وَيْحَكَ وَمَنْ يَحُولُ بَيْنَكَ وَبَيْنَ التَّوْبَةِ اخْرُجْ مِنَ الْقَرْيَةِ الْخَبِيثَةِ الَّتِي أَنْتَ فِيهَا إِلَى الْقَرْيَةِ الصَّالِحَةِ قَرْيَةِ كَذَا وَكَذَا فَاعْبُدْ رَبَّكَ فِيهَا ‏.‏ فَخَرَجَ يُرِيدُ الْقَرْيَةَ الصَّالِحَةَ فَعَرَضَ لَهُ أَجَلُهُ فِي الطَّرِيقِ فَاخْتَصَمَتْ فِيهِ مَلاَئِكَةُ الرَّحْمَةِ وَمَلاَئِكَةُ الْعَذَابِ قَالَ إِبْلِيسُ أَنَا أَوْلَى بِهِ إِنَّهُ لَمْ يَعْصِنِي سَاعَةً قَطُّ ‏.‏ قَالَ فَقَالَتْ مَلاَئِكَةُ الرَّحْمَةِ إِنَّهُ خَرَجَ تَائِبًا ‏"‏ ‏.‏ قَالَ هَمَّامٌ فَحَدَّثَنِي حُمَيْدٌ الطَّوِيلُ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي رَافِعٍ، قَالَ فَبَعَثَ اللَّهُ عَزَّ وَجَلَّ مَلَكًا فَاخْتَصَمُوا إِلَيْهِ ثُمَّ رَجَعُوا فَقَالَ انْظُرُوا أَىَّ الْقَرْيَتَيْنِ كَانَتْ أَقْرَبَ فَأَلْحِقُوهُ بِأَهْلِهَا ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا هَمَّامُ بْنُ يَحْيَى، عَنْ قَتَادَةَ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَلاَ أُخْبِرُكُمْ بِمَا، سَمِعْتُ مِنْ، فِي رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏"‏ إِنَّ عَبْدًا قَتَلَ تِسْعَةً وَتِسْعِينَ نَفْسًا ثُمَّ عَرَضَتْ لَهُ التَّوْبَةُ فَسَأَلَ عَنْ أَعْلَمِ أَهْلِ الأَرْضِ فَدُلَّ عَلَى رَجُلٍ فَأَتَاهُ ‏.‏ فَقَالَ إِنِّي قَتَلْتُ تِسْعَةً وَتِسْعِينَ نَفْسًا فَهَلْ لِي مِنْ تَوْبَةٍ قَالَ بَعْدَ تِسْعَةٍ وَتِسْعِينَ نَفْسًا ‏.‏ قَالَ فَانْتَضَى سَيْفَهُ فَقَتَلَهُ فَأَكْمَلَ بِهِ الْمِائَةَ ثُمَّ عَرَضَتْ لَهُ التَّوْبَةُ فَسَأَلَ عَنْ أَعْلَمِ أَهْلِ الأَرْضِ فَدُلَّ عَلَى رَجُلٍ فَأَتَاهُ فَقَالَ إِنِّي قَتَلْتُ مِائَةَ نَفْسٍ فَهَلْ لِي مِنْ تَوْبَةٍ قَالَ فَقَالَ وَيْحَكَ وَمَنْ يَحُولُ بَيْنَكَ وَبَيْنَ التَّوْبَةِ اخْرُجْ مِنَ الْقَرْيَةِ الْخَبِيثَةِ الَّتِي أَنْتَ فِيهَا إِلَى الْقَرْيَةِ الصَّالِحَةِ قَرْيَةِ كَذَا وَكَذَا فَاعْبُدْ رَبَّكَ فِيهَا ‏.‏ فَخَرَجَ يُرِيدُ الْقَرْيَةَ الصَّالِحَةَ فَعَرَضَ لَهُ أَجَلُهُ فِي الطَّرِيقِ فَاخْتَصَمَتْ فِيهِ مَلاَئِكَةُ الرَّحْمَةِ وَمَلاَئِكَةُ الْعَذَابِ قَالَ إِبْلِيسُ أَنَا أَوْلَى بِهِ إِنَّهُ لَمْ يَعْصِنِي سَاعَةً قَطُّ ‏.‏ قَالَ فَقَالَتْ مَلاَئِكَةُ الرَّحْمَةِ إِنَّهُ خَرَجَ تَائِبًا ‏"‏ ‏.‏ قَالَ هَمَّامٌ فَحَدَّثَنِي حُمَيْدٌ الطَّوِيلُ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي رَافِعٍ، قَالَ فَبَعَثَ اللَّهُ عَزَّ وَجَلَّ مَلَكًا فَاخْتَصَمُوا إِلَيْهِ ثُمَّ رَجَعُوا فَقَالَ انْظُرُوا أَىَّ الْقَرْيَتَيْنِ كَانَتْ أَقْرَبَ فَأَلْحِقُوهُ بِأَهْلِهَا ‏.‏ قَالَ قَتَادَةُ فَحَدَّثَنَا الْحَسَنُ، قَالَ لَمَّا حَضَرَهُ الْمَوْتُ احْتَفَزَ بِنَفْسِهِ فَقَرُبَ مِنَ الْقَرْيَةِ الصَّالِحَةِ وَبَاعَدَ مِنْهُ الْقَرْيَةَ الْخَبِيثَةَ فَأَلْحَقُوهُ بِأَهْلِ الْقَرْيَةِ الصَّالِحَةِ ‏.‏ قَالَ أَبُو الْحَسَنِ الْقَطَّانُ حَدَّثَنَا أَبُو الْعَبَّاسِ بْنُ عَبْدِ اللَّهِ بْنِ إِسْمَاعِيلَ الْبَغْدَادِيُّ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا هَمَّامٌ، فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2622}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Sa'eed Al Khudri said:“Shall I not tell you what I heard directly from the Messenger of Allah (ﷺ)? I heard it and memorized it: 'A man killed ninety-nine people, then the idea of repentance occurred to him. He asked who was the most knowledgeable of people on earth, and he was told of a man so he went to him and said: “I have killed ninety-nine people. Can I repent?” He said: “After ninety-nine people?!” He said: 'So he drew his sword and killed him, thus completing one hundred. Then the idea of repentance occurred to him (again), so he asked who was the most knowledgeable of people, and he was told of a man (so he went to him) and said: “I have killed one hundred people. Can I repent?” He said: “Woe to you, what is stopping you from repenting? Leave the evil town where you are living and go to a good town, such and such town and worship your Lord there.” So he went out, heading for the good town, but death came to him on the road. The angels of mercy and angels of punishment argued over him. Iblis (Satan) said: “I have more right to him, for he never disobeyed me for a moment.” But the angels of mercy said: “He went out repenting.” (One of the narrators) Hammam said: “Humaid At-Tawil narrated to me from Bakr bin Abdullah that Abu Rafi said: 'So Allah (SWT) sent an angel to whom they referred (the case). He said: “Look and see which of the two towns was he closer, and put him with its people.” (One of the narrators) Qatadah said: “Hasan narrated to us: 'When death came to him he strove and drew closer to the good town, and farther away from the evil town, so they put him with the people of the good town.”}}
\hadithdefcmd{ibnmajah}{2623}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، وَعَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، جَمِيعًا عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الْحَارِثِ بْنِ فُضَيْلٍ، أَظُنُّهُ عَنِ ابْنِ أَبِي الْعَوْجَاءِ، وَاسْمُهُ، سُفْيَانُ عَنْ أَبِي شُرَيْحٍ الْخُزَاعِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أُصِيبَ بِدَمٍ أَوْ خَبْلٍ - وَالْخَبْلُ الْجُرْحُ - فَهُوَ بِالْخِيَارِ بَيْنَ إِحْدَى ثَلاَثٍ فَإِنْ أَرَادَ الرَّابِعَةَ فَخُذُوا عَلَى يَدَيْهِ أَنْ يَقْتُلَ أَوْ يَعْفُوَ أَوْ يَأْخُذَ الدِّيَةَ فَمَنْ فَعَلَ شَيْئًا مِنْ ذَلِكَ فَعَادَ فَإِنَّ لَهُ نَارَ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا ‏"‏ ‏.‏\hadithno{2623}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sharaih Al-Khuzai that the Messenger of Allah (ﷺ) said:“Whoever suffers from killing or wounding, has the choice of three things, and if he wants the fourth then restrain him. He may kill (the killer), or forgive him, or take the blood money. Whoever accepts any of these (options), then kills (the killer) after that will have the fire of hell to abide therein forever.”}}
\hadithdefcmd{ibnmajah}{2624}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ لَهُ قَتِيلٌ فَهُوَ بِخَيْرِ النَّظَرَيْنِ إِمَّا أَنْ يَقْتُلَ وَإِمَّا أَنْ يُفْدَى ‏"‏ ‏.‏\hadithno{2624}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“If a person's relative is killed, he has the choice of two things: He may either have the killer killed, or he may demand the blood money.”}}
\hadithdefcmd{ibnmajah}{2625}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ زَيْدِ بْنِ ضُمَيْرَةَ، حَدَّثَنِي أَبِي وَعَمِّي، وَكَانَا، شَهِدَا حُنَيْنًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالاَ صَلَّى النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ ثُمَّ جَلَسَ تَحْتَ شَجَرَةٍ فَقَامَ إِلَيْهِ الأَقْرَعُ بْنُ حَابِسٍ - وَهُوَ سَيِّدُ خِنْدِفَ يَرُدُّ - عَنْ دَمِ مُحَلِّمِ بْنِ جَثَّامَةَ وَقَامَ عُيَيْنَةُ بْنُ حِصْنٍ يَطْلُبُ بِدَمِ عَامِرِ بْنِ الأَضْبَطِ وَكَانَ أَشْجَعِيًّا فَقَالَ لَهُمُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَقْبَلُونَ الدِّيَةَ ‏"‏ ‏.‏ فَأَبَوْا فَقَامَ رَجُلٌ مِنْ بَنِي لَيْثٍ يُقَالُ لَهُ مُكَيْتِلٌ فَقَالَ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا شَبَّهْتُ هَذَا الْقَتِيلَ فِي غُرَّةِ الإِسْلاَمِ إِلاَّ كَغَنَمٍ وَرَدَتْ فَرُمِيَتْ فَنَفَرَ آخِرُهَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَكُمْ خَمْسُونَ فِي سَفَرِنَا وَخَمْسُونَ إِذَا رَجَعْنَا ‏"‏ ‏.‏ فَقَبِلُوا الدِّيَةَ ‏.‏\hadithno{2625}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ziyad bin Sa'd bin Dumairah (said):“My father and my paternal uncle, who were present at Hunain with the Messenger of Allah (ﷺ) narrated to me: 'The Prophet (ﷺ) prayed Zuhr, then he sat beneath a tree. Aqra' bin Habis, who was the chief of Khindaf, came to him arguing in defense of Muhallim bin Jaththamah. Uyainah bin Hisn came to him demanding vengeance for 'Amir bin Adbat who was from the tribe of Ashja. The Prophet (ﷺ) said to them: “Will you accept the blood money?'” But they refused. Then a man from Banu Laith, whose name was Mukaital, stood up and said: 'O Messenger of Allah (ﷺ)! By Allah (SWT)! This man who was killed in the early days of Islam is like Sheep that come to drink but stones are thrown at them, so the last of them runs away (i.e. ,the murderer should be killed).' The Prophet (ﷺ) said: 'You will have fifty (camels) while we are traveling and fifty (camels) when we return.' So they accepted the blood money.”}}
\hadithdefcmd{ibnmajah}{2626}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَتَلَ عَمْدًا دُفِعَ إِلَى أَوْلِيَاءِ الْقَتِيلِ فَإِنْ شَاءُوا قَتَلُوا وَإِنْ شَاءُوا أَخَذُوا الدِّيَةَ وَذَلِكَ ثَلاَثُونَ حِقَّةً وَثَلاَثُونَ جَذَعَةً وَأَرْبَعُونَ خَلِفَةً وَذَلِكَ عَقْلُ الْعَمْدِ مَا صُولِحُوا عَلَيْهِ فَهُوَ لَهُمْ وَذَلِكَ تَشْدِيدُ الْعَقْلِ ‏"‏ ‏.‏\hadithno{2626}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from this father, from his grandfather that the Messenger of Allah (ﷺ) said:“Whoever kills deliberately, he will be handed over to the heirs of the victim. If they want, they may kill him, or if they want, they may accept the blood money, which is thirty Hiqqah, thirty Jadha'ah and forty Khalifah. This is the blood money for deliberate slaying. Whatever is settled by reconciliation belongs to them, and that is a binding covenant.”}}
\hadithdefcmd{ibnmajah}{2627}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَيُّوبَ، سَمِعْتُ الْقَاسِمَ بْنَ رَبِيعَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَتِيلُ الْخَطَإِ شِبْهِ الْعَمْدِ قَتِيلُ السَّوْطِ وَالْعَصَا مِائَةٌ مِنَ الإِبِلِ أَرْبَعُونَ مِنْهَا خَلِفَةً فِي بُطُونِهَا أَوْلاَدُهَا ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنِ الْقَاسِمِ بْنِ رَبِيعَةَ، عَنْ عُقْبَةَ بْنِ أَوْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2627}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abdullah bin 'Amr that the Prophet (ﷺ) said:“Killing by mistake that resembles intentionally, is killing with a whip or stick, for which the blood money is one hundred camels, of which forty should be pregnant she-camels in middle of their pregnancies, with their young in their wombs.” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{2628}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ جُدْعَانَ، سَمِعَهُ مِنَ الْقَاسِمِ بْنِ رَبِيعَةَ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ يَوْمَ فَتْحِ مَكَّةَ وَهُوَ عَلَى دَرَجِ الْكَعْبَةِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ فَقَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي صَدَقَ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ أَلاَ إِنَّ قَتِيلَ الْخَطَإِ قَتِيلَ السَّوْطِ وَالْعَصَا فِيهِ مِائَةٌ مِنَ الإِبِلِ مِنْهَا أَرْبَعُونَ خَلِفَةً فِي بُطُونِهَا أَوْلاَدُهَا أَلاَ إِنَّ كَلَّ مَأْثُرَةٍ كَانَتْ فِي الْجَاهِلِيَّةِ وَدَمٍ تَحْتَ قَدَمَىَّ هَاتَيْنِ إِلاَّ مَا كَانَ مِنْ سِدَانَةِ الْبَيْتِ وَسِقَايَةِ الْحَاجِّ أَلاَ إِنِّي قَدْ أَمْضَيْتُهُمَا لأَهْلِهِمَا كَمَا كَانَا ‏"‏ ‏.‏\hadithno{2628}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Umar that :the Messenger of Allah (ﷺ) stood up on the Day of the conquest of Makkah, on the steps of the Ka'bah. He praised and glorified Allah (SWT), then he said: “Praise is to Allah (SWT) who has fulfilled His promise, granted victory to His slave and defeated the Confederates alone. The one who is killed by mistake is the one who is killed with a whip or a stick; for him the blood money is one hundred camels, of which forty should be pregnant she-camels with their youngs in their wombs. Every custom of Ignorance period, and every blood claim, is beneath these two feet of mine (i.e. is abolished), except for the custodianship of the Ka'bah and the provision of water for the pilgrims, which I confirm still belong to the people to whom they belonged before.”}}
\hadithdefcmd{ibnmajah}{2629}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هَانِئٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ جَعَلَ الدِّيَةَ اثْنَىْ عَشَرَ أَلْفًا ‏.‏\hadithno{2629}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that :the Messenger of Allah (ﷺ) set the blood money at twelve thousand (Dirham)}}
\hadithdefcmd{ibnmajah}{2630}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ الْمَرْوَزِيُّ، أَنْبَأَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا مُحَمَّدُ بْنُ رَاشِدٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قُتِلَ خَطَأً فَدِيَتُهُ مِنَ الإِبِلِ ثَلاَثُونَ بِنْتَ مَخَاضٍ وَثَلاَثُونَ ابْنَةَ لَبُونٍ وَثَلاَثُونَ حِقَّةً وَعَشَرَةُ بَنِي لَبُونٍ ‏"‏ ‏.‏ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَوِّمُهَا عَلَى أَهْلِ الْقُرَى أَرْبَعَمِائَةِ دِينَارٍ أَوْ عَدْلَهَا مِنَ الْوَرِقِ وَيُقَوِّمُهَا عَلَى أَزْمَانِ الإِبِلِ إِذَا غَلَتْ رَفَعَ فِي ثَمَنِهَا وَإِذَا هَانَتْ نَقَصَ مِنْ ثَمَنِهَا عَلَى نَحْوِ الزَّمَانِ مَا كَانَ فَبَلَغَ قِيمَتُهَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا بَيْنَ الأَرْبَعِمِائَةِ دِينَارٍ إِلَى ثَمَانِمِائَةِ دِينَارٍ أَوْ عَدْلُهَا مِنَ الْوَرِقِ ثَمَانِيَةُ آلاَفِ دِرْهَمٍ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ مَنْ كَانَ عَقْلُهُ فِي الْبَقَرِ عَلَى أَهْلِ الْبَقَرِ مِائَتَىْ بَقَرَةٍ وَمَنْ كَانَ عَقْلُهُ فِي الشَّاءِ عَلَى أَهْلِ الشَّاءِ أَلْفَىْ شَاةٍ ‏.‏\hadithno{2630}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:“Whoever is killed by mistake, his blood money in camels is thirty Bint Makhad (a one-year-old she-camel), thirty Bint Labun (a two-year-old she-camel), thirty Hiqqah (a three-year-old she-camel) and ten Bani Labun (two-years-old male-camel).” The Messenger of Allah (ﷺ) used to fix the value (of the blood money for accidental killing) among town-dwellers at four hundred Dinar or the equivalent value in silver. When he calculated the price in terms of camels (for Bedouins), it would vary from one time to another. When prices roses, the value (in dinars) would rise: and when prices fell, the value (in Dinar) would fall. At the time of the Messenger of Allah (ﷺ) the value was between four hundred and eight hundred dinar, or the equivalent value in silver, eight thousand Dirham. And the Messenger of Allah (ﷺ) ruled that if a person's blood money was paid in cattle, among those who kept cattle, the amount was two hundred cows; and if person's blood money was paid in sheep, among those who kept sheep, the value was two thousand sheep. (Hasan)}}
\hadithdefcmd{ibnmajah}{2631}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ عَاصِمٍ، حَدَّثَنَا الصَّبَّاحُ بْنُ مُحَارِبٍ، حَدَّثَنَا حَجَّاجُ بْنُ أَرْطَاةَ، حَدَّثَنَا زَيْدُ بْنُ جُبَيْرٍ، عَنْ خِشْفِ بْنِ مَالِكٍ الطَّائِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِي دِيَةِ الْخَطَإِ عِشْرُونَ حِقَّةً وَعِشْرُونَ جَذَعَةً وَعِشْرُونَ بِنْتَ مَخَاضٍ وَعِشْرُونَ بِنْتَ لَبُونٍ وَعِشْرُونَ بَنِي مَخَاضٍ ذُكُورٍ ‏"‏ ‏.‏\hadithno{2631}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Masud that the Messenger of Allah (ﷺ) said:“The blood money of one who killed by mistake is twenty Hiqqah (three-year-old she camels), twenty Jadha'ah (four year old she camels), twenty Bint Makhad (one year old she camel), twenty Bint Labun (two year old she camels), and twenty Bani Makhad (one year old she camels).”}}
\hadithdefcmd{ibnmajah}{2632}{حَدَّثَنَا الْعَبَّاسُ بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَعَلَ الدِّيَةَ اثْنَىْ عَشَرَ أَلْفًا قَالَ ذَلِكَ قَوْلُهُ ‏\{وَمَا نَقَمُوا إِلاَّ أَنْ أَغْنَاهُمُ اللَّهُ وَرَسُولُهُ مِنْ فَضْلِهِ\}‏ قَالَ بِأَخْذِهِمُ الدِّيَةَ ‏.‏\hadithno{2632}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Ikrimah, from Ibn 'Abbas, that :the Prophet (ﷺ) set the blood money at twelve thousand (Dirham). He said: “This is what Allah says: 'And they could not find any cause to do so except that Allah and his Messenger (ﷺ) had enriched them of His bounty.'” He said: “By their taking the blood money.”}}
\hadithdefcmd{ibnmajah}{2633}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبِي، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عُبَيْدِ بْنِ نَضْلَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالدِّيَةِ عَلَى الْعَاقِلَةِ ‏.‏\hadithno{2633}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Mughirah bin Shu'bah said:“The Messenger of Allah (ﷺ) ruled that the blood money must be paid by the 'Aqilah.”}}
\hadithdefcmd{ibnmajah}{2634}{حَدَّثَنَا يَحْيَى بْنُ دُرُسْتَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ عَلِيِّ بْنِ أَبِي طَلْحَةَ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ أَبِي عَامِرٍ الْهَوْزَنِيِّ، عَنِ الْمِقْدَامِ الشَّامِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا وَارِثُ مَنْ لاَ وَارِثَ لَهُ أَعْقِلُ عَنْهُ وَأَرِثُهُ وَالْخَالُ وَارِثُ مَنْ لاَ وَارِثَ لَهُ يَعْقِلُ عَنْهُ وَيَرِثُهُ ‏"‏ ‏.‏\hadithno{2634}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Miqdam Ash-Shami that the Messenger of Allah (ﷺ) said:“I am the heir of the one who has no heir, and I will pay blood money on his behalf and inherit from him, and the maternal uncle is the heir of the one who has no heir; he pays the blood money on his behalf and inherits from him.'”}}
\hadithdefcmd{ibnmajah}{2635}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَتَلَ فِي عِمِّيَّةٍ أَوْ عَصَبِيَّةٍ بِحَجَرٍ أَوْ سَوْطٍ أَوْ عَصًا فَعَلَيْهِ عَقْلُ الْخَطَإِ وَمَنْ قَتَلَ عَمْدًا فَهُوَ قَوَدٌ وَمَنْ حَالَ بَيْنَهُ وَبَيْنَهُ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ ‏"‏ ‏.‏\hadithno{2635}\hadithgrade{Muhammad Fouad Abd al-Baqi: Batil; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas, who attributed it to the Prophet (ﷺ):“Whoever kills out of folly or for tribal motives, using a rock, a whip, or a stick; he must pay the blood money for killing by mistake. Whoever kills deliberately, he is to be killed in retaliation. Whoever tries to prevent that, upon him is the curse of Allah, the angels and all the people, and no change nor equitable exchange will be accepted from him.”}}
\hadithdefcmd{ibnmajah}{2636}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَعَمَّارُ بْنُ خَالِدٍ الْوَاسِطِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ دَهْثَمِ بْنِ قُرَّانَ، حَدَّثَنِي نِمْرَانُ بْنُ جَارِيَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، ضَرَبَ رَجُلاً عَلَى سَاعِدِهِ بِالسَّيْفِ فَقَطَعَهَا مِنْ غَيْرِ مَفْصِلٍ فَاسْتَعْدَى عَلَيْهِ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَ لَهُ بِالدِّيَةِ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ الْقِصَاصَ ‏.‏ فَقَالَ ‏ "‏ خُذِ الدِّيَةَ بَارَكَ اللَّهُ لَكَ فِيهَا ‏"‏ ‏.‏ وَلَمْ يَقْضِ لَهُ بِالْقِصَاصِ ‏.‏\hadithno{2636}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Nimran bin Jariyah narrated from his father that :a man struck another man on the wrist with his sword and severed it, not at the joint. He appealed to the Prophet (ﷺ) who ordered that the Diyah be paid. The man said: “O Messenger of Allah (ﷺ), I want retaliation.” He said: “Take the compensation and may Allah bless you therein.” And he did not rule that he be allowed retaliation}}
\hadithdefcmd{ibnmajah}{2637}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ مُعَاذِ بْنِ مُحَمَّدٍ الأَنْصَارِيِّ، عَنِ ابْنِ صُهْبَانَ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ قَوَدَ فِي الْمَأْمُومَةِ وَلاَ الْجَائِفَةِ وَلاَ الْمُنَقِّلَةِ ‏"‏ ‏.‏\hadithno{2637}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abbas bin 'Abdul-Muttalib that the Messenger of Allah (ﷺ) said:“There is no retaliation for a head wound that does not reach the brain, a spear wound that does not penetrate deeply, or a wound that dislocates a bone.”}}
\hadithdefcmd{ibnmajah}{2638}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَبَا جَهْمِ بْنَ حُذَيْفَةَ مُصَدِّقًا فَلاَجَّهُ رَجُلٌ فِي صَدَقَتِهِ فَضَرَبَهُ أَبُو جَهْمٍ فَشَجَّهُ فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا الْقَوَدَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَكُمْ كَذَا وَكَذَا ‏"‏ ‏.‏ فَلَمْ يَرْضَوْا فَقَالَ ‏"‏ لَكُمْ كَذَا وَكَذَا ‏"‏ ‏.‏ فَرَضُوا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي خَاطِبٌ عَلَى النَّاسِ وَمُخْبِرُهُمْ بِرِضَاكُمْ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَخَطَبَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ هَؤُلاَءِ اللَّيْثِيِّينِ أَتَوْنِي يُرِيدُونَ الْقَوَدَ فَعَرَضْتُ عَلَيْهِمْ كَذَا وَكَذَا أَرَضِيتُمْ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ فَهَمَّ بِهِمُ الْمُهَاجِرُونَ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَكُفُّوا فَكَفُّوا ثُمَّ دَعَاهُمْ فَزَادَهُمْ فَقَالَ ‏"‏ أَرَضِيتُمْ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ إِنِّي خَاطِبٌ عَلَى النَّاسِ وَمُخْبِرُهُمْ بِرِضَاكُمْ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَخَطَبَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ أَرَضِيتُمْ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ابْنُ مَاجَهْ سَمِعْتُ مُحَمَّدَ بْنَ يَحْيَى يَقُولُ تَفَرَّدَ بِهَذَا مَعْمَرٌ لاَ أَعْلَمُ رَوَاهُ غَيْرُهُ ‏.‏\hadithno{2638}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that :the Messenger of Allah (ﷺ) sent Abu Jahm bin Hudhaifah to collect Sadaqah. A man disputed with him concerning his Sadaqah, and Abu Jahm struck him and wounded his head. They came to Prophet (ﷺ) and said: “Compensatory money, O Messenger of Allah (ﷺ)!” The Prophet (ﷺ) said: “You will have such and such,” but they did not accept that. He said: “You will have such and such,” and they agreed. Then the Prophet (ﷺ) said: “I am going to address the people and tell them that you agreed.” They said: “Yes.” So the Prophet (ﷺ) addressed (the people) and said: “These people of Laith came to me seeking compensatory money, and I have offered them such and such. Do you agree?” They said: “No.” The Emigrants wanted to attack them, but the Prophet (ﷺ) told them not to, so they refrained. Then he called them and offered them more and said: “Do you agree?” They said: “Yes.” He said: “I am going to address the people and tell them that you agreed.” They said: “Yes.” So the Prophet (ﷺ) addressed (the people) then said: “Do you Agree?” They said: “Yes.”}}
\hadithdefcmd{ibnmajah}{2639}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْجَنِينِ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ فَقَالَ الَّذِي قُضِيَ عَلَيْهِ أَنَعْقِلُ مَنْ لاَ شَرِبَ وَلاَ أَكَلْ وَلاَ صَاحَ وَلاَ اسْتَهَلّ وَمِثْلُ ذَلِكَ يُطَلّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذَا لَيَقُولُ بِقَوْلِ شَاعِرٍ فِيهِ غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ ‏"‏ ‏.‏\hadithno{2639}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) ruled concerning a fetus that (the blood money) was a slave, male and female. The one against whom this verdict was passed said: ' Should we pay blood money for one who neither ate, drunk, shouted, nor cried, (at the moment of birth)? One such as this should be overlooked .' The Messenger of Allah (ﷺ) said: 'This man speaks like a poet. (But the blood money for a fetus is) a slave, male, or female.'”}}
\hadithdefcmd{ibnmajah}{2640}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ اسْتَشَارَ عُمَرُ بْنُ الْخَطَّابِ النَّاسَ فِي إِمْلاَصِ الْمَرْأَةِ يَعْنِي سِقْطَهَا فَقَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ شَهِدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِيهِ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ ‏.‏ فَقَالَ عُمَرُ ائْتِنِي بِمَنْ يَشْهَدُ مَعَكَ ‏.‏ فَشَهِدَ مَعَهُ مُحَمَّدُ بْنُ مَسْلَمَةَ ‏.‏\hadithno{2640}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Miswar bin Makhramah said:“Umar bin Khattab consulted the people concerning a woman who had been caused to miscarry. Al-Mughirah bin Shu'bah said: 'I saw the messenger of Allah (ﷺ) rule that a slave, male or female, be given as blood money (for a fetus).' 'Umar said: 'Bring me someone who will testify alongside you. So he brought Muhammad bin Maslamah to testify along with him.'”}}
\hadithdefcmd{ibnmajah}{2641}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنِي ابْنُ جُرَيْجٍ، حَدَّثَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ طَاوُسًا، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّهُ نَشَدَ النَّاسَ قَضَاءَ النَّبِيِّ صلى الله عليه وسلم فِي ذَلِكَ يَعْنِي فِي الْجَنِينِ فَقَامَ حَمَلُ بْنُ مَالِكِ بْنِ النَّابِغَةِ فَقَالَ كُنْتُ بَيْنَ امْرَأَتَيْنِ لِي فَضَرَبَتْ إِحْدَاهُمَا الأُخْرَى بِمِسْطَحٍ فَقَتَلَتْهَا وَقَتَلَتْ جَنِينَهَا فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْجَنِينِ بِغُرَّةٍ عَبْدٍ وَأَنْ تُقْتَلَ بِهَا ‏.‏\hadithno{2641}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Umar bin Khattab that :he asked the people about the ruling of the Prophet (ﷺ) concerning that - concerning a fetus. Hamal bin Malik bin Nabighah stood up and said: “I was between my two wives and one of them struck the other with a tent-pole, killing her and a fetus. The Messenger of Allah (ﷺ) ruled that the blood money for the fetus was a slave, and that she would be killed in retaliation.”}}
\hadithdefcmd{ibnmajah}{2642}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ، كَانَ يَقُولُ الدِّيَةُ لِلْعَاقِلَةِ وَلاَ تَرِثُ الْمَرْأَةُ مِنْ دِيَةِ زَوْجِهَا شَيْئًا حَتَّى كَتَبَ إِلَيْهِ الضَّحَّاكُ بْنُ سُفْيَانَ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَرَّثَ امْرَأَةَ أَشْيَمَ الضِّبَابِيِّ مِنْ دِيَةِ زَوْجِهَا ‏.‏\hadithno{2642}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sa'eed bin Musayyab that 'Umar used to say:“The blood money is for the near male relatives from the father's side and the wife does not inherit anything from the blood money of her husband,” until Ad-Dahhak bin Sufyan wrote to him, and told him that the Prophet (ﷺ) ruled that the wife of Ashyam bin Dibabi should inherit from the blood money of her husband}}
\hadithdefcmd{ibnmajah}{2643}{حَدَّثَنَا عَبْدُ رَبِّهِ بْنُ خَالِدٍ النُّمَيْرِيُّ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ إِسْحَاقَ بْنِ يَحْيَى بْنِ الْوَلِيدِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى لِحَمَلِ بْنِ مَالِكٍ الْهُذَلِيِّ اللِّحْيَانِيِّ بِمِيرَاثِهِ مِنَ امْرَأَتِهِ الَّتِي قَتَلَتْهَا امْرَأَتُهُ الأُخْرَى ‏.‏\hadithno{2643}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ubadah bin Samit:That the Prophet (ﷺ) ruled that Hamal bin Malik Hudhali Al-Lihyani should inherit from his wife who was killed by his other wife}}
\hadithdefcmd{ibnmajah}{2644}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَيَّاشٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّ عَقْلَ أَهْلِ الْكِتَابَيْنِ نِصْفُ عَقْلِ الْمُسْلِمِينَ وَهُمُ الْيَهُودُ وَالنَّصَارَى ‏.‏\hadithno{2644}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his grandfather, that :the Messenger of Allah (ﷺ) ruled that the blood money for the people of the book is half of that of the blood money for the Muslims, and they are the Jews and Christians}}
\hadithdefcmd{ibnmajah}{2645}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ إِسْحَاقَ بْنِ أَبِي فَرْوَةَ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْقَاتِلُ لاَ يَرِثُ ‏"‏ ‏.‏\hadithno{2645}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (ﷺ) said: “The killer does not inherit.”}}
\hadithdefcmd{ibnmajah}{2646}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ أَبَا قَتَادَةَ، - رَجُلٌ مِنْ بَنِي مُدْلِجٍ - قَتَلَ ابْنَهُ فَأَخَذَ مِنْهُ عُمَرُ مِائَةً مِنَ الإِبِلِ ثَلاَثِينَ حِقَّةً وَثَلاَثِينَ جَذَعَةً وَأَرْبَعِينَ خَلِفَةً ‏.‏ فَقَالَ أَيْنَ أَخُو الْمَقْتُولِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ لِقَاتِلٍ مِيرَاثٌ ‏"‏ ‏.‏\hadithno{2646}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib that :Abu Qatadah, a man from Banu Mudlij, killed his son, and 'Umar took one hundred camels from him, thirty Hiqqah, thirty Jadha'ah and forty Khalifah. Then he said: “Where is the brother of slain? I heard the Messenger of Allah (ﷺ) say: 'The killer does not inherit.'”}}
\hadithdefcmd{ibnmajah}{2647}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا مُحَمَّدُ بْنُ رَاشِدٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَعْقِلَ الْمَرْأَةَ عَصَبَتُهَا مَنْ كَانُوا وَلاَ يَرِثُوا مِنْهَا شَيْئًا إِلاَّ مَا فَضَلَ عَنْ وَرَثَتِهَا وَإِنْ قُتِلَتْ فَعَقْلُهَا بَيْنَ وَرَثَتِهَا فَهُمْ يَقْتُلُونَ قَاتِلَهَا ‏"‏ ‏.‏\hadithno{2647}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) ruled that a woman's blood money (if she kills someone) should be paid by her male relatives on her father's side, whoever they are, and they should not inherit anything from her, except what is left over after her heirs have been taken their shares. If she is killed than her blood money is to be shared among her heirs, since they are the ones who may kill the one who killed her.”}}
\hadithdefcmd{ibnmajah}{2648}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْمُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا مُجَالِدٌ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرٍ، قَالَ جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الدِّيَةَ عَلَى عَاقِلَةِ الْقَاتِلَةِ فَقَالَتْ عَاقِلَةُ الْمَقْتُولَةِ يَا رَسُولَ اللَّهِ مِيرَاثُهَا لَنَا ‏.‏ قَالَ ‏ "‏ لاَ مِيرَاثُهَا لِزَوْجِهَا وَوَلَدِهَا ‏"‏ ‏.‏\hadithno{2648}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) ruled that the blood money should be paid by the near male relations from the father's side of the killer, and the such relatives of slain woman said: 'O Messenger of Allah (ﷺ),her legacy is for us.' He said: 'No, her legacy is for her husband and children.'”}}
\hadithdefcmd{ibnmajah}{2649}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى أَبُو مُوسَى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، وَابْنُ أَبِي عَدِيٍّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَسَرَتِ الرُّبَيِّعُ عَمَّةُ أَنَسٍ ثَنِيَّةَ جَارِيَةٍ فَطَلَبُوا الْعَفْوَ فَأَبَوْا فَعَرَضَ عَلَيْهِمُ الأَرْشَ فَأَبَوْا فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَأَمَرَ بِالْقِصَاصِ ‏.‏ فَقَالَ أَنَسُ بْنُ النَّضْرِ يَا رَسُولَ اللَّهِ تُكْسَرُ ثَنِيَّةُ الرُّبَيِّعِ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ تُكْسَرُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا أَنَسُ كِتَابُ اللَّهِ الْقِصَاصُ ‏"‏ ‏.‏ قَالَ فَرَضِيَ الْقَوْمُ فَعَفَوْا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ مَنْ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏ ‏.‏\hadithno{2649}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:“Rubai, the paternal aunt of Anas, broke the tooth of a girl and they (her family) asked (the girl's family) to let her off, but they refused. They offered to pay compensatory money, but they refused. So they came to Prophet (ﷺ) who ordered retaliation. Anas bin Nadr said: 'O Messenger of Allah (ﷺ), will the tooth of Rubai' be broken? By the One Who sent you with the truth, it will not be broken!' The Prophet (ﷺ) said: 'O Anas, what Allah has decreed is retaliation.' So the people accepted that and forgave her. The Messenger of Allah (ﷺ) said: 'there are among the slaves of Allah those who, if they swear by Allah, Allah fulfills their oath.'”}}
\hadithdefcmd{ibnmajah}{2650}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنِي شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الأَسْنَانُ سَوَاءٌ الثَّنِيَّةُ وَالضِّرْسُ سَوَاءٌ ‏"‏ ‏.‏\hadithno{2650}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:“Teeth are all the same; the incisor and the molar are the same.”}}
\hadithdefcmd{ibnmajah}{2651}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الْبَالِسِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ شَقِيقٍ، حَدَّثَنَا أَبُو حَمْزَةَ الْمَرْوَزِيُّ، حَدَّثَنَا يَزِيدُ النَّحْوِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَضَى فِي السِّنِّ خَمْسًا مِنَ الإِبِلِ ‏.‏\hadithno{2651}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that :the Prophet (ﷺ) ruled that (the compensatory money) for a tooth was five camels}}
\hadithdefcmd{ibnmajah}{2652}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، وَابْنُ أَبِي عَدِيٍّ، قَالُوا حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ هَذِهِ وَهَذِهِ سَوَاءٌ ‏"‏ ‏.‏ يَعْنِي الْخِنْصَرَ وَالإِبْهَامَ ‏.‏\hadithno{2652}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) said:“This and this are the same” - meaning the pinky finger, ring finger and thumb}}
\hadithdefcmd{ibnmajah}{2653}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ الْعَتَكِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ مَطَرٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الأَصَابِعُ سَوَاءٌ كُلُّهُنَّ فِيهِنَّ عَشْرٌ عَشْرٌ مِنَ الإِبِلِ ‏"‏ ‏.‏\hadithno{2653}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:“The fingers are all same, and (the compensatory money) for each of them is ten camels}}
\hadithdefcmd{ibnmajah}{2654}{حَدَّثَنَا رَجَاءُ بْنُ الْمُرَجَّى السَّمَرْقَنْدِيُّ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ غَالِبٍ التَّمَّارِ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ مَسْرُوقِ بْنِ أَوْسٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الأَصَابِعُ سَوَاءٌ ‏"‏ ‏.‏\hadithno{2654}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Musa Al-Ash'ari that the Messenger of Allah (ﷺ) said:“The fingers are the same.”}}
\hadithdefcmd{ibnmajah}{2655}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ مَطَرٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْمَوَاضِحِ خَمْسٌ خَمْسٌ مِنَ الإِبِلِ ‏"‏ ‏.‏\hadithno{2655}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that the Prophet (ﷺ) of said:“For a wound that exposes a bone, is five; (the compensation) is five camels.”}}
\hadithdefcmd{ibnmajah}{2656}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ عَبْدِ اللَّهِ، عَنْ عَمَّيْهِ، يَعْلَى وَسَلَمَةَ ابْنَىْ أُمَيَّةَ قَالاَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ وَمَعَنَا صَاحِبٌ لَنَا فَاقْتَتَلَ هُوَ وَرَجُلٌ آخَرُ وَنَحْنُ بِالطَّرِيقِ ‏.‏ قَالَ فَعَضَّ الرَّجُلُ يَدَ صَاحِبِهِ فَجَذَبَ صَاحِبُهُ يَدَهُ مِنْ فِيهِ فَطَرَحَ ثَنِيَّتَهُ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْتَمِسُ عَقْلَ ثَنِيَّتِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَعْمِدُ أَحَدُكُمْ إِلَى أَخِيهِ فَيَعَضُّهُ كَعِضَاضِ الْفَحْلِ ثُمَّ يَأْتِي يَلْتَمِسُ الْعَقْلَ لاَ عَقْلَ لَهَا ‏"‏ ‏.‏ قَالَ فَأَبْطَلَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2656}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ya'la and Salamah the sons of Ummayah said:“We went out with the Messenger of Allah (ﷺ) on the military expedition of Tabuk, and with us was a friend of ours. He fought with another man while we were on the road. The man bit the hand on his opponent, who pulled away his hand and the man's tooth fell out. He came to Messenger of Allah (ﷺ) demanding compensatory money for his tooth, and the Messenger of Allah (ﷺ) said: 'Would anyone of you go and bite his brother like a stallion, then come demanding compensatory money? There is no compensatory for this.'” Hence, The Messenger of Allah (ﷺ) invalidated it (i.e compensatory in such case)}}
\hadithdefcmd{ibnmajah}{2657}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، عَضَّ رَجُلاً عَلَى ذِرَاعِهِ فَنَزَعَ يَدَهُ فَوَقَعَتْ ثَنِيَّتُهُ فَرُفِعَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَبْطَلَهَا ‏.‏ وَقَالَ ‏ "‏ يَقْضَمُ أَحَدُكُمْ كَمَا يَقْضَمُ الْفَحْلُ ‏"‏ ‏.‏\hadithno{2657}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Imran bin Husain that a :man bit another man on his forearm; he pulled away his arm away and the man’s tooth fell out. The matter was referred to Prophet (ﷺ) who invalidated it and said: 'Would one of you bite (another) like a stallion?'”}}
\hadithdefcmd{ibnmajah}{2658}{حَدَّثَنَا عَلْقَمَةُ بْنُ عَمْرٍو الدَّارِمِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ مُطَرِّفٍ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي جُحَيْفَةَ، قَالَ قُلْتُ لِعَلِيِّ بْنِ أَبِي طَالِبٍ هَلْ عِنْدَكُمْ شَىْءٌ مِنَ الْعِلْمِ لَيْسَ عِنْدَ النَّاسِ قَالَ لاَ وَاللَّهِ مَا عِنْدَنَا إِلاَّ مَا عِنْدَ النَّاسِ إِلاَّ أَنْ يَرْزُقَ اللَّهُ رَجُلاً فَهْمًا فِي الْقُرْآنِ أَوْ مَا فِي هَذِهِ الصَّحِيفَةِ فِيهَا الدِّيَاتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنْ لاَ يُقْتَلَ مُسْلِمٌ بِكَافِرٍ ‏.‏\hadithno{2658}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Juhaifah said:“I said to 'Ali bin Abu Talib: 'Do you have any knowledge that the people do not have?' He said: 'No, by Allah, we only know what the people know, except that Allah may bless a man with understanding of Qur'an or what is in this sheet, in which are mentioned the rulings on blood money from the Messenger of Allah (ﷺ) and it says that a Muslim should not be killed in retaliation for the murder of disbeliever.'”}}
\hadithdefcmd{ibnmajah}{2659}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَيَّاشٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُقْتَلُ مُسْلِمٌ بِكَافِرٍ ‏"‏ ‏.‏\hadithno{2659}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:“A Muslim should not be killed in retaliation for the murder of a disbeliever.”}}
\hadithdefcmd{ibnmajah}{2660}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ حَنَشٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقْتَلُ مُؤْمِنٌ بِكَافِرٍ وَلاَ ذُو عَهْدٍ فِي عَهْدِهِ ‏"‏ ‏.‏\hadithno{2660}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) said:”A believer should not be killed in retaliation for the murder of a disbeliever, and a person who has a treaty should not be killed during the time of the treaty.”}}
\hadithdefcmd{ibnmajah}{2661}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقْتَلُ بِالْوَلَدِ الْوَالِدُ ‏"‏ ‏.‏\hadithno{2661}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:“A father should not be killed for his son.”}}
\hadithdefcmd{ibnmajah}{2662}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَجَّاجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يُقْتَلُ الْوَالِدُ بِالْوَلَدِ ‏"‏ ‏.‏\hadithno{2662}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that 'Umar bin Khattab said:“I heard the Messenger of Allah (ﷺ) say: 'A father should not be killed for his son.'”}}
\hadithdefcmd{ibnmajah}{2663}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَتَلَ عَبْدَهُ قَتَلْنَاهُ وَمَنْ جَدَعَهُ جَدَعْنَاهُ ‏"‏ ‏.‏\hadithno{2663}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Samurah bin Jundab that the Messenger of Allah (ﷺ) said:“Whoever kills his slave, we will kill him, and whoever mutilates (his slave) we will mutilate him.”}}
\hadithdefcmd{ibnmajah}{2664}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ الطَّبَّاعِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي فَرْوَةَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، وَعَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَتَلَ رَجُلٌ عَبْدَهُ عَمْدًا مُتَعَمِّدًا فَجَلَدَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِائَةً وَنَفَاهُ سَنَةً وَمَحَا سَهْمَهُ مِنَ الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{2664}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:“A man killed his slave deliberately and with malice aforethought, so the Messenger of Allah (ﷺ) gave him one hundred lashes, banished him for one year, and cancelled his share from among the Muslims.”}}
\hadithdefcmd{ibnmajah}{2665}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هَمَّامِ بْنِ يَحْيَى، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ يَهُودِيًّا، رَضَخَ رَأْسَ امْرَأَةٍ بَيْنَ حَجَرَيْنِ فَقَتَلَهَا فَرَضَخَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَأْسَهُ بَيْنَ حَجَرَيْنِ ‏.‏\hadithno{2665}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that :a Jew crushed the head of a woman between two rocks and killed her, so the Messenger of Allah (ﷺ) crushed his head between two rocks}}
\hadithdefcmd{ibnmajah}{2666}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ يَهُودِيًّا، قَتَلَ جَارِيَةً عَلَى أَوْضَاحٍ لَهَا فَقَالَ لَهَا ‏ "‏ أَقَتَلَكِ فُلاَنٌ ‏"‏ ‏.‏ فَأَشَارَتْ بِرَأْسِهَا أَنْ لاَ ثُمَّ سَأَلَهَا الثَّانِيَةَ فَأَشَارَتْ بِرَأْسِهَا أَنْ لاَ ثُمَّ سَأَلَهَا الثَّالِثَةَ فَأَشَارَتْ بِرَأْسِهَا أَنْ نَعَمْ فَقَتَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ حَجَرَيْنِ ‏.‏\hadithno{2666}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that :a Jew killed a girl for her jewelry. He asked her (as she was dying): “Did so-and-so kill you?” and she gestured with her head to say no. Then he asked her again, and she gestured with her head to say no. he asked her a third time and she gestured with her head to say yes. So the Messenger of Allah (ﷺ) killed him (by crushing his head) between two rocks}}
\hadithdefcmd{ibnmajah}{2667}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُسْتَمِرِّ الْعُرُوقِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ سُفْيَانَ، عَنْ جَابِرٍ، عَنْ أَبِي عَازِبٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ قَوَدَ إِلاَّ بِالسَّيْفِ ‏"‏ ‏.‏\hadithno{2667}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Nu'man bin Bashir that the Messenger of Allah (ﷺ) said:“There is no retaliation except with the sword.”}}
\hadithdefcmd{ibnmajah}{2668}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُسْتَمِرِّ، حَدَّثَنَا الْحُرُّ بْنُ مَالِكٍ الْعَنْبَرِيُّ، حَدَّثَنَا مُبَارَكُ بْنُ فَضَالَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ قَوَدَ إِلاَّ بِالسَّيْفِ ‏"‏ ‏.‏\hadithno{2668}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Bakrah that the Messenger of Allah (ﷺ) said:“There is no retaliation except with the sword.”}}
\hadithdefcmd{ibnmajah}{2669}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي حِجَّةِ الْوَدَاعِ ‏ "‏ أَلاَ لاَ يَجْنِي جَانٍ إِلاَّ عَلَى نَفْسِهِ لاَ يَجْنِي وَالِدٌ عَلَى وَلَدِهِ وَلاَ مَوْلُودٌ عَلَى وَالِدِهِ ‏"‏ ‏.‏\hadithno{2669}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sulaiman bin Amr bin Ahwas that his father said:I heard the Messenger of Allah (ﷺ) saying during the Farewell pilgrimage: “No criminal commits a crime but he brings. (the punishment for that) upon himself. No father can bring punishment upon his son by his crime, and no son can bring punishment upon his father.”}}
\hadithdefcmd{ibnmajah}{2670}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، حَدَّثَنَا جَامِعُ بْنُ شَدَّادٍ، عَنْ طَارِقٍ الْمُحَارِبِيِّ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْفَعُ يَدَيْهِ حَتَّى رَأَيْتُ بَيَاضَ إِبْطَيْهِ يَقُولُ ‏ "‏ أَلاَ لاَ تَجْنِي أُمٌّ عَلَى وَلَدٍ أَلاَ لاَ تَجْنِي أُمٌّ عَلَى وَلَدٍ ‏"‏ ‏.‏\hadithno{2670}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Tariq Al-Muharibi said:“I saw the Messenger of Allah (ﷺ) raising his hands until I saw the whiteness of his armpits, saying: 'No child should be punished because of his mother's crime, no child should be punished because of his mother's crime.”}}
\hadithdefcmd{ibnmajah}{2671}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ يُونُسَ، عَنْ حُصَيْنِ بْنِ أَبِي الْحُرِّ، عَنِ الْخَشْخَاشِ الْعَنْبَرِيِّ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَمَعِي ابْنِي فَقَالَ ‏ "‏ لاَ تَجْنِي عَلَيْهِ وَلاَ يَجْنِي عَلَيْكَ ‏"‏ ‏.‏\hadithno{2671}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Khashkhash Al-Anbari said:“I came to the Prophet (ﷺ) and my son was with me. He said: 'You will not be punished because of his crime and he will not be punished because of yours.'”}}
\hadithdefcmd{ibnmajah}{2672}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عَقِيلٍ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا أَبُو الْعَوَّامِ الْقَطَّانُ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ أُسَامَةَ بْنِ شَرِيكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَجْنِي نَفْسٌ عَلَى أُخْرَى ‏"‏ ‏.‏\hadithno{2672}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Usamah bin Sharik that the Messenger of Allah (ﷺ) said:“No person will be punished because of another's crime.”}}
\hadithdefcmd{ibnmajah}{2673}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعَجْمَاءُ جَرْحُهَا جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَالْبِئْرُ جُبَارٌ ‏"‏ ‏.‏\hadithno{2673}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Allah's Messenger (ﷺ) said:“The injuries caused by the beast are without liability, and wells are without liability, and mines are without liability.”}}
\hadithdefcmd{ibnmajah}{2674}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْعَجْمَاءُ جَرْحُهَا جُبَارٌ وَالْمَعْدِنُ جُبَارٌ ‏"‏ ‏.‏\hadithno{2674}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Khathir bin 'Abdullah bin 'Amr bin 'Awf narrated that his grandfather said:“I heard the Messenger of Allah (ﷺ) say: 'The injuries cause by the beast are without liability, and mines are without liability.”}}
\hadithdefcmd{ibnmajah}{2675}{حَدَّثَنَا عَبْدُ رَبِّهِ بْنُ خَالِدٍ النُّمَيْرِيُّ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنِي مُوسَى بْنُ عُقْبَةَ، حَدَّثَنِي إِسْحَاقُ بْنُ يَحْيَى بْنِ الْوَلِيدِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ الْمَعْدِنَ جُبَارٌ وَالْبِئْرَ جُبَارٌ وَالْعَجْمَاءُ جَرْحُهَا جُبَارٌ ‏.‏ وَالْعَجْمَاءُ الْبَهِيمَةُ مِنَ الأَنْعَامِ وَغَيْرِهَا ‏.‏ وَالْجُبَارُ هُوَ الْهَدَرُ الَّذِي لاَ يُغَرَّمُ ‏.‏\hadithno{2675}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ubadah bin Samit said:“The Messenger of Allah (ﷺ) ruled that there is no liability for injuries caused by falling into a mines or a well, nor those caused by a beast.”}}
\hadithdefcmd{ibnmajah}{2676}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ النَّارُ جُبَارٌ وَالْبِئْرُ جُبَارٌ ‏"‏ ‏.‏\hadithno{2676}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“(The injuries caused by) a fire are without liability, and by falling into a well.”}}
\hadithdefcmd{ibnmajah}{2677}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، سَمِعْتُ مَالِكَ بْنَ أَنَسٍ، حَدَّثَنِي أَبُو لَيْلَى بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّهُ أَخْبَرَهُ عَنْ رِجَالٍ، مِنْ كُبَرَاءِ قَوْمِهِ أَنَّ عَبْدَ، اللَّهِ بْنَ سَهْلٍ وَمُحَيِّصَةَ خَرَجَا إِلَى خَيْبَرَ مِنْ جَهْدٍ أَصَابَهُمْ فَأُتِيَ مُحَيِّصَةُ فَأُخْبِرَ أَنَّ عَبْدَ اللَّهِ بْنَ سَهْلٍ قَدْ قُتِلَ وَأُلْقِيَ فِي فَقِيرٍ أَوْ عَيْنٍ بِخَيْبَرَ فَأَتَى يَهُودَ فَقَالَ أَنْتُمْ وَاللَّهِ قَتَلْتُمُوهُ ‏.‏ قَالُوا وَاللَّهِ مَا قَتَلْنَاهُ ‏.‏ ثُمَّ أَقْبَلَ حَتَّى قَدِمَ عَلَى قَوْمِهِ فَذَكَرَ ذَلِكَ لَهُمْ ثُمَّ أَقْبَلَ هُوَ وَأَخُوهُ حُوَيِّصَةُ وَهُوَ أَكْبَرُ مِنْهُ وَعَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ فَذَهَبَ مُحَيِّصَةُ يَتَكَلَّمُ وَهُوَ الَّذِي كَانَ بِخَيْبَرَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمُحَيِّصَةَ ‏"‏ كَبِّرْ كَبِّرْ ‏"‏ ‏.‏ يُرِيدُ السِّنَّ فَتَكَلَّمَ حُوَيِّصَةُ ثُمَّ تَكَلَّمَ مُحَيِّصَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِمَّا أَنْ يَدُوا صَاحِبَكُمْ وَإِمَّا أَنْ يُؤْذِنُوا بِحَرْبٍ ‏"‏ ‏.‏ فَكَتَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَيْهِمْ فِي ذَلِكَ فَكَتَبُوا إِنَّا وَاللَّهِ مَا قَتَلْنَاهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِحُوَيِّصَةَ وَمُحَيِّصَةَ وَعَبْدِ الرَّحْمَنِ ‏"‏ تَحْلِفُونَ وَتَسْتَحِقُّونَ دَمَ صَاحِبِكُمْ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَتَحْلِفُ لَكُمْ يَهُودُ ‏"‏ ‏.‏ قَالُوا لَيْسُوا بِمُسْلِمِينَ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ فَبَعَثَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم مِائَةَ نَاقَةٍ حَتَّى أُدْخِلَتْ عَلَيْهِمُ الدَّارَ فَقَالَ سَهْلٌ فَلَقَدْ رَكَضَتْنِي مِنْهَا نَاقَةٌ حَمْرَاءُ ‏.‏\hadithno{2677}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sahl bin Abu Hathmah from the elders of his people that :'Abdullah bin Sahl and Muhayyishah set out for Khaibar because of some problem that had arisen. Someone came to Muhayyishah, and he told him that Abdullah bin Sahl had been killed and thrown into a pit or well in Khaibar. He came to the Jews and said: “By Allah, you killed him.” They said: “By Allah, we did not kill him.” Then he went back to his people and told them about that. Then he and his brother Huwayyisah, who was older than him, and 'Abdur-Rahman bin Sahl, came (to the Prophet (ﷺ)). Muhayyisah, who was the one who had been at Khaibar, went and he began to speak, but the Messenger of Allah (ﷺ) said: “Let the elder speak first.” So Huwayyisah spoke, then Muhayyisah spoke. The Messenger of Allah (ﷺ) said: “Either (the Jews) will pay the blood money for your companion, or war will be declared on them.” The Messenger of Allah (ﷺ) sent a letter to that effect (to the Jews) and they wrote back saying: “By Allah, we did not kill him.” The Messenger of Allah (ﷺ) said to Huwayyisah, Muhayyisah and Abdur-Rahman: “Will you swear an oath establishing your claim to the blood money of your companion?” They said: “No” He said: “Should the Jews swear an oath for you?” They said: “They are not Muslims.” So the Messenger of Allah (ﷺ) paid the blood money himself, and he sent one hundred she-camels to them and some of them entered the house. Sahl said: “A red she-camels from among them kicked me.”}}
\hadithdefcmd{ibnmajah}{2678}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَجَّاجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ حُوَيِّصَةَ، وَمُحَيِّصَةَ، ابْنَىْ مَسْعُودٍ وَعَبْدَ اللَّهِ وَعَبْدَ الرَّحْمَنِ ابْنَىْ سَهْلٍ خَرَجُوا يَمْتَارُونَ بِخَيْبَرَ فَعُدِيَ عَلَى عَبْدِ اللَّهِ فَقُتِلَ فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ تُقْسِمُونَ وَتَسْتَحِقُّونَ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ كَيْفَ نُقْسِمُ وَلَمْ نَشْهَدْ قَالَ ‏"‏ فَتُبْرِئُكُمْ يَهُودُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِذًا تَقْتُلُنَا ‏.‏ قَالَ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ ‏.‏\hadithno{2678}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that :Huwayyisah and Muhayyisah , the sons of Mas'ud, and 'Abdullah and 'Abdur-Rahman the sons of Sahl, went out to search for food in Khaibar. 'Abdullah was attacked and killed, and mention of that was made to the Messenger of Allah (ﷺ). He said: “Will you swear an oath and establish your right to blood money?” They said: “O Messenger of Allah (ﷺ), how can we swear an oath when we did not witness anything?” He said: “Do you want the Jews to swear that they are innocent?” They said: “O Messenger of Allah (ﷺ), then they will kill us too.” So the Messenger of Allah (ﷺ) paid the blood money himself}}
\hadithdefcmd{ibnmajah}{2679}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ السَّلاَمِ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي فَرْوَةَ، عَنْ سَلَمَةَ بْنِ رَوْحِ بْنِ زِنْبَاعٍ، عَنْ جَدِّهِ، أَنَّهُ قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَقَدْ خَصَى غُلاَمًا لَهُ فَأَعْتَقَهُ النَّبِيُّ صلى الله عليه وسلم بِالْمُثْلَةِ ‏.‏\hadithno{2679}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salamah bin Rawh bin Zinba', that :his grandfather came to the Prophet (ﷺ) and he had castrated a slave of his. The Prophet (ﷺ) manumitted the slave in compensation for having been mutilated}}
\hadithdefcmd{ibnmajah}{2680}{حَدَّثَنَا رَجَاءُ بْنُ الْمُرَجَّى السَّمَرْقَنْدِيُّ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا أَبُو حَمْزَةَ الصَّيْرَفِيُّ، حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم صَارِخًا فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَكَ ‏"‏ ‏.‏ قَالَ سَيِّدِي رَآنِي أُقَبِّلُ جَارِيَةً لَهُ فَجَبَّ مَذَاكِيرِي ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَىَّ بِالرَّجُلِ ‏"‏ ‏.‏ فَطُلِبَ فَلَمْ يُقْدَرْ عَلَيْهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اذْهَبْ فَأَنْتَ حُرٌّ ‏"‏ ‏.‏ قَالَ عَلَى مَنْ نُصْرَتِي يَا رَسُولَ اللَّهِ قَالَ يَقُولُ أَرَأَيْتَ إِنِ اسْتَرَقَّنِي مَوْلاَىَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَلَى كُلِّ مُؤْمِنٍ أَوْ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{2680}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib narrated from his father that his grandfather said:“A man came to the Prophet (ﷺ) screaming. The Messenger of Allah (ﷺ) said to him: 'What is the matter with you?' He said: 'My master saw me kissing a slave woman of his, so he cut off my penis.' The Prophet (ﷺ) said: 'Take me to the man.' He was sought but could not be found, so the Messenger of Allah (ﷺ) said: 'Go, for you are free.' He said: 'Who will protect me, O Messenger of Allah (ﷺ)? What if my master enslaves me again?' The Messenger of Allah (ﷺ) said: 'Your protection will be (incumbent upon) every believer or Muslim.'”}}
\hadithdefcmd{ibnmajah}{2681}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا هُشَيْمٌ، عَنْ مُغِيرَةَ، عَنْ شِبَاكٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ قَالَ عَبْدُ اللَّهِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَعَفِّ النَّاسِ قِتْلَةً أَهْلَ الإِيمَانِ ‏"‏ ‏.‏\hadithno{2681}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah said that the Messenger of Allah (ﷺ) said:“The most decent of the people in killing are the people of faith.”}}
\hadithdefcmd{ibnmajah}{2682}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ مُغِيرَةَ، عَنْ شِبَاكٍ، عَنْ إِبْرَاهِيمَ، عَنْ هُنَىِّ بْنِ نُوَيْرَةَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَعَفَّ النَّاسِ قِتْلَةً أَهْلُ الإِيمَانِ ‏"‏ ‏.‏\hadithno{2682}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah that the Messenger of Allah (ﷺ) said:“The most decent people in killing are the people of faith.”}}
\hadithdefcmd{ibnmajah}{2683}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ حَنَشٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْلِمُونَ تَتَكَافَأُ دِمَاؤُهُمْ وَهُمْ يَدٌ عَلَى مَنْ سِوَاهُمْ يَسْعَى بِذِمَّتِهِمْ أَدْنَاهُمْ وَيُرَدُّ عَلَى أَقْصَاهُمْ ‏"‏ ‏.‏\hadithno{2683}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) said:“The blood of every Muslims is equal, they are one hand against others. The asylum offered by the lowest of them in status applies to them (all), and the return is granted to the farthest of them.”}}
\hadithdefcmd{ibnmajah}{2684}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ أَبُو ضَمْرَةَ، عَنْ عَبْدِ السَّلاَمِ بْنِ أَبِي الْجَنُوبِ، عَنِ الْحَسَنِ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُسْلِمُونَ يَدٌ عَلَى مَنْ سِوَاهُمْ وَتَتَكَافَأُ دِمَاؤُهُمْ ‏"‏ ‏.‏\hadithno{2684}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ma'qil bin Yasar that the Messenger of Allah (ﷺ) said:“The Muslims are one hand against others, and their blood is equal.”}}
\hadithdefcmd{ibnmajah}{2685}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَيَّاشٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَدُ الْمُسْلِمِينَ عَلَى مَنْ سِوَاهُمْ تَتَكَافَأُ دِمَاؤُهُمْ وَيُجِيرُ عَلَى الْمُسْلِمِينَ أَدْنَاهُمْ وَيَرُدُّ عَلَى الْمُسْلِمِينَ أَقْصَاهُمْ ‏"‏ ‏.‏\hadithno{2685}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather that the Messenger of Allah (ﷺ) said:“The hand of the Muslims is over others, and their blood and wealth is equal in value. The (asylum granted by) the lowest of them applies to the Muslims, and the Muslims return (the spoils of war) to the farthest of them.”}}
\hadithdefcmd{ibnmajah}{2686}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الْحَسَنِ بْنِ عَمْرٍو، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَتَلَ مُعَاهِدًا لَمْ يَرَحْ رَائِحَةَ الْجَنَّةِ وَإِنَّ رِيحَهَا لَيُوجَدُ مِنْ مَسِيرَةِ أَرْبَعِينَ عَامًا ‏"‏ ‏.‏\hadithno{2686}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that the Messenger of Allah (ﷺ) said:“Whoever kills a Mu'ahid, will not smell the fragrance of Paradise, even though its fragrance may be detected from a distance of forty years.”}}
\hadithdefcmd{ibnmajah}{2687}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مَعْدِيُّ بْنُ سُلَيْمَانَ، أَنْبَأَنَا ابْنُ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَتَلَ مُعَاهِدًا لَهُ ذِمَّةُ اللَّهِ وَذِمَّةُ رَسُولِهِ لَمْ يَرَحْ رَائِحَةَ الْجَنَّةِ وَإِنَّ رِيحَهَا لَيُوجَدُ مِنْ مَسِيرَةِ سَبْعِينَ عَامًا ‏"‏ ‏.‏\hadithno{2687}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever kills a Mu'ahid who has the protection of Allah and the protection of his Messenger, will not smell the fragrance of Paradise, even though its fragrance may be detected from a distance of Seventy years.”}}
\hadithdefcmd{ibnmajah}{2688}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِفَاعَةَ بْنِ شَدَّادٍ الْقِتْبَانِيِّ، قَالَ لَوْلاَ كَلِمَةٌ سَمِعْتُهَا مِنْ، عَمْرِو بْنِ الْحَمِقِ الْخُزَاعِيِّ لَمَشَيْتُ فِيمَا بَيْنَ رَأْسِ الْمُخْتَارِ وَجَسَدِهِ سَمِعْتُهُ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَمِنَ رَجُلاً عَلَى دَمِهِ فَقَتَلَهُ فَإِنَّهُ يَحْمِلُ لِوَاءَ غَدْرٍ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2688}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Rifa'ah bin Shaddad Al-Qitbani said:“Were it not for a word that I heard from 'Amr bin Hamiq Khuza'i, I would have separated the head of Al-Mukhtar from his body. I heard him saying: “The Messenger of Allah (ﷺ) said: 'If a man trusts someone with his life then he kills him, he will carry a banner of treachery on the day of Resurrection.'”}}
\hadithdefcmd{ibnmajah}{2689}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبُو لَيْلَى، عَنْ أَبِي عُكَّاشَةَ، عَنْ رِفَاعَةَ، قَالَ دَخَلْتُ عَلَى الْمُخْتَارِ فِي قَصْرِهِ فَقَالَ قَامَ جِبْرَائِيلُ مِنْ عِنْدِي السَّاعَةَ ‏.‏ فَمَا مَنَعَنِي مِنْ ضَرْبِ عُنُقِهِ إِلاَّ حَدِيثٌ سَمِعْتُهُ مِنْ سُلَيْمَانَ بْنِ صُرَدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا أَمِنَكَ الرَّجُلُ عَلَى دَمِهِ فَلاَ تَقْتُلْهُ ‏"‏ ‏.‏ فَذَاكَ الَّذِي مَنَعَنِي مِنْهُ ‏.‏\hadithno{2689}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Rifa'ah said:“I entered upon Mukhtar in his palace and he said: 'Jibril has just left me.' Nothing stopped me from striking his neck (i.e, killing him) but a Hadith that I heard from Sulaiman bin Surad, according to which the Prophet (ﷺ) said: 'If a man trusts you with his life, then do not kill him.' That is what stopped me.”}}
\hadithdefcmd{ibnmajah}{2690}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَتَلَ رَجُلٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرُفِعَ ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَدَفَعَهُ إِلَى وَلِيِّ الْمَقْتُولِ فَقَالَ الْقَاتِلُ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا أَرَدْتُ قَتْلَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْوَلِيِّ ‏ "‏ أَمَا إِنَّهُ إِنْ كَانَ صَادِقًا ثُمَّ قَتَلْتَهُ دَخَلْتَ النَّارَ ‏"‏ ‏.‏ قَالَ فَخَلَّى سَبِيلَهُ ‏.‏ قَالَ وَكَانَ مَكْتُوفًا بِنِسْعَةٍ فَخَرَجَ يَجُرُّ نِسْعَتَهُ فَسُمِّيَ ذَا النِّسْعَةِ ‏.‏\hadithno{2690}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“A man killed (another) during the time of the Messenger of Allah (ﷺ) and was referred to the Prophet (ﷺ). He handed him over to the victim's next of kin, but the killer said: 'O Messenger of Allah (ﷺ), by Allah I did not mean to kill him.' The Messenger of Allah (ﷺ) said to the next of kin, 'If he is telling the truth and you kill him, you will go to Hell.' So he let him go. He had been tied with a rope, and he went out dragging his rope, so he became known as Dhan-Nis'ah (the one with the rope)}}
\hadithdefcmd{ibnmajah}{2691}{حَدَّثَنَا أَبُو عُمَيْرٍ، عِيسَى بْنُ مُحَمَّدٍ النَّحَّاسُ وَعِيسَى بْنُ يُونُسَ وَالْحُسَيْنُ بْنُ أَبِي السَّرِيِّ الْعَسْقَلاَنِيُّ قَالُوا حَدَّثَنَا ضَمْرَةُ بْنُ رَبِيعَةَ، عَنِ ابْنِ شَوْذَبٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَتَى رَجُلٌ بِقَاتِلِ وَلِيِّهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اعْفُ ‏"‏ ‏.‏ فَأَبَى فَقَالَ ‏"‏ خُذْ أَرْشَكَ ‏"‏ ‏.‏ فَأَبَى ‏.‏ قَالَ ‏"‏ اذْهَبْ فَاقْتُلْهُ فَإِنَّكَ مِثْلُهُ ‏"‏ ‏.‏ قَالَ فَلُحِقَ بِهِ فَقِيلَ لَهُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ قَالَ ‏"‏ اقْتُلْهُ فَإِنَّكَ مِثْلُهُ ‏"‏ ‏.‏ فَخَلَّى سَبِيلَهُ ‏.‏ قَالَ فَرُئِيَ يَجُرُّ نِسْعَتَهُ ذَاهِبًا إِلَى أَهْلِهِ ‏.‏ قَالَ كَأَنَّهُ قَدْ كَانَ أَوْثَقَهُ ‏.‏ قَالَ أَبُو عُمَيْرٍ فِي حَدِيثِهِ قَالَ ابْنُ شَوْذَبٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، فَلَيْسَ لأَحَدٍ بَعْدَ النَّبِيِّ صلى الله عليه وسلم أَنْ يَقُولَ ‏"‏ اقْتُلْهُ فَإِنَّكَ مِثْلُهُ ‏"‏ ‏.‏ قَالَ ابْنُ مَاجَهْ هَذَا حَدِيثُ الرَّمْلِيِّينَ لَيْسَ إِلاَّ عِنْدَهُمْ ‏.‏\hadithno{2691}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“A man brought the killer of his relative to the Messenger of Allah (ﷺ) and the Messenger of Allah (ﷺ) said: 'Pardon him,' but the refused. He said: 'Take the blood money,' but he refused. He said: 'Go and kill him, but then you will be like him.’ Someone caught up with him and reminded him that the Messenger of Allah (ﷺ) had said: 'Go and kill him, but then you will be like him.’ So he let him go. He said: So he was seen dragging his strap going to his family. He said: It seemed that he had tied him up. It's narrated that AbdurRahman bin AlQasim said "Then it is not (permissible) for anyone after the Prophet ﷺ to say 'Go and kill him, but then you will be like him}}
\hadithdefcmd{ibnmajah}{2692}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ الْمُزَنِيُّ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، قَالَ لاَ أَعْلَمُهُ إِلاَّ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا رُفِعَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم شَىْءٌ فِيهِ الْقِصَاصُ إِلاَّ أَمَرَ فِيهِ بِالْعَفْوِ ‏.‏\hadithno{2692}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Ata bin Abu Maimunah said:“I only know it from Anas bin Malik who said: 'No case involving retaliation was referred to the Messenger of Allah (ﷺ) but he enjoined forgiveness.”}}
\hadithdefcmd{ibnmajah}{2693}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ أَبِي السَّفَرِ، قَالَ قَالَ أَبُو الدَّرْدَاءِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ رَجُلٍ يُصَابُ بِشَىْءٍ مِنْ جَسَدِهِ فَيَتَصَدَّقُ بِهِ إِلاَّ رَفَعَهُ اللَّهُ بِهِ دَرَجَةً أَوْ حَطَّ عَنْهُ بِهِ خَطِيئَةً ‏"‏ ‏.‏ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏.‏\hadithno{2693}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Darda said:“I heard the Messenger of Allah (ﷺ) say: 'There is no man who suffers some (injury) on his body and forgives (the perpetrator), but Allah (SWT) will raise him one degree in status thereby, or erase from him one sin.'My own ears heard it and my heart memorized it.”}}
\hadithdefcmd{ibnmajah}{2694}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو صَالِحٍ، عَنِ ابْنِ لَهِيعَةَ، عَنِ ابْنِ أَنْعُمٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، حَدَّثَنَا مُعَاذُ بْنُ جَبَلٍ، وَأَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ وَعُبَادَةُ بْنُ الصَّامِتِ وَشَدَّادُ بْنُ أَوْسٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَرْأَةُ إِذَا قَتَلَتْ عَمْدًا لاَ تُقْتَلُ حَتَّى تَضَعَ مَا فِي بَطْنِهَا إِنْ كَانَتْ حَامِلاً وَحَتَّى تُكَفِّلَ وَلَدَهَا وَإِنْ زَنَتْ لَمْ تُرْجَمْ حَتَّى تَضَعَ مَا فِي بَطْنِهَا وَحَتَّى تُكَفِّلَ وَلَدَهَا ‏"‏ ‏.‏\hadithno{2694}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh bin Jabal, Abu Ubaidah bin Jararah, Ubadah bin Samit and Shaddad bin Aws narrated that the Messenger of Allah (ﷺ) said:“If a woman kills someone deliberately, she should not be killed until she delivers what is in her womb, if she is pregnant, and until the child's sponsorship is guaranteed. And if a woman commits illegal sex, she should not be stoned until she delivers what is in her womb and until her child's sponsorship is guaranteed.”}}
